# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class ConnectorSyncSettingsDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'user_id': 'str',
        'connector_id': 'str',
        'sync_enabled': 'bool',
        'sync_schedule_type': 'str',
        'sync_interval': 'int'
    }

    attribute_map = {
        'id': 'id',
        'user_id': 'userId',
        'connector_id': 'connectorId',
        'sync_enabled': 'syncEnabled',
        'sync_schedule_type': 'syncScheduleType',
        'sync_interval': 'syncInterval'
    }

    def __init__(self, id=None, user_id=None, connector_id=None, sync_enabled=None, sync_schedule_type=None, sync_interval=None, local_vars_configuration=None):  # noqa: E501
        """ConnectorSyncSettingsDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._user_id = None
        self._connector_id = None
        self._sync_enabled = None
        self._sync_schedule_type = None
        self._sync_interval = None
        self.discriminator = None

        self.id = id
        self.user_id = user_id
        self.connector_id = connector_id
        self.sync_enabled = sync_enabled
        self.sync_schedule_type = sync_schedule_type
        self.sync_interval = sync_interval

    @property
    def id(self):
        """Gets the id of this ConnectorSyncSettingsDto.  # noqa: E501


        :return: The id of this ConnectorSyncSettingsDto.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ConnectorSyncSettingsDto.


        :param id: The id of this ConnectorSyncSettingsDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def user_id(self):
        """Gets the user_id of this ConnectorSyncSettingsDto.  # noqa: E501


        :return: The user_id of this ConnectorSyncSettingsDto.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this ConnectorSyncSettingsDto.


        :param user_id: The user_id of this ConnectorSyncSettingsDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and user_id is None:  # noqa: E501
            raise ValueError("Invalid value for `user_id`, must not be `None`")  # noqa: E501

        self._user_id = user_id

    @property
    def connector_id(self):
        """Gets the connector_id of this ConnectorSyncSettingsDto.  # noqa: E501


        :return: The connector_id of this ConnectorSyncSettingsDto.  # noqa: E501
        :rtype: str
        """
        return self._connector_id

    @connector_id.setter
    def connector_id(self, connector_id):
        """Sets the connector_id of this ConnectorSyncSettingsDto.


        :param connector_id: The connector_id of this ConnectorSyncSettingsDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and connector_id is None:  # noqa: E501
            raise ValueError("Invalid value for `connector_id`, must not be `None`")  # noqa: E501

        self._connector_id = connector_id

    @property
    def sync_enabled(self):
        """Gets the sync_enabled of this ConnectorSyncSettingsDto.  # noqa: E501


        :return: The sync_enabled of this ConnectorSyncSettingsDto.  # noqa: E501
        :rtype: bool
        """
        return self._sync_enabled

    @sync_enabled.setter
    def sync_enabled(self, sync_enabled):
        """Sets the sync_enabled of this ConnectorSyncSettingsDto.


        :param sync_enabled: The sync_enabled of this ConnectorSyncSettingsDto.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and sync_enabled is None:  # noqa: E501
            raise ValueError("Invalid value for `sync_enabled`, must not be `None`")  # noqa: E501

        self._sync_enabled = sync_enabled

    @property
    def sync_schedule_type(self):
        """Gets the sync_schedule_type of this ConnectorSyncSettingsDto.  # noqa: E501


        :return: The sync_schedule_type of this ConnectorSyncSettingsDto.  # noqa: E501
        :rtype: str
        """
        return self._sync_schedule_type

    @sync_schedule_type.setter
    def sync_schedule_type(self, sync_schedule_type):
        """Sets the sync_schedule_type of this ConnectorSyncSettingsDto.


        :param sync_schedule_type: The sync_schedule_type of this ConnectorSyncSettingsDto.  # noqa: E501
        :type: str
        """
        allowed_values = [None,"INTERVAL"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and sync_schedule_type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `sync_schedule_type` ({0}), must be one of {1}"  # noqa: E501
                .format(sync_schedule_type, allowed_values)
            )

        self._sync_schedule_type = sync_schedule_type

    @property
    def sync_interval(self):
        """Gets the sync_interval of this ConnectorSyncSettingsDto.  # noqa: E501


        :return: The sync_interval of this ConnectorSyncSettingsDto.  # noqa: E501
        :rtype: int
        """
        return self._sync_interval

    @sync_interval.setter
    def sync_interval(self, sync_interval):
        """Sets the sync_interval of this ConnectorSyncSettingsDto.


        :param sync_interval: The sync_interval of this ConnectorSyncSettingsDto.  # noqa: E501
        :type: int
        """

        self._sync_interval = sync_interval

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ConnectorSyncSettingsDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ConnectorSyncSettingsDto):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class PhoneProvisioningJobItemDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'phone_number': 'str',
        'provider_label': 'str',
        'status': 'str',
        'line_type': 'str',
        'carrier_name': 'str',
        'mobile_country_code': 'str',
        'mobile_network_code': 'str',
        'phone_number_id': 'str',
        'failure_message': 'str'
    }

    attribute_map = {
        'id': 'id',
        'phone_number': 'phoneNumber',
        'provider_label': 'providerLabel',
        'status': 'status',
        'line_type': 'lineType',
        'carrier_name': 'carrierName',
        'mobile_country_code': 'mobileCountryCode',
        'mobile_network_code': 'mobileNetworkCode',
        'phone_number_id': 'phoneNumberId',
        'failure_message': 'failureMessage'
    }

    def __init__(self, id=None, phone_number=None, provider_label=None, status=None, line_type=None, carrier_name=None, mobile_country_code=None, mobile_network_code=None, phone_number_id=None, failure_message=None, local_vars_configuration=None):  # noqa: E501
        """PhoneProvisioningJobItemDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._phone_number = None
        self._provider_label = None
        self._status = None
        self._line_type = None
        self._carrier_name = None
        self._mobile_country_code = None
        self._mobile_network_code = None
        self._phone_number_id = None
        self._failure_message = None
        self.discriminator = None

        self.id = id
        self.phone_number = phone_number
        if provider_label is not None:
            self.provider_label = provider_label
        self.status = status
        if line_type is not None:
            self.line_type = line_type
        if carrier_name is not None:
            self.carrier_name = carrier_name
        if mobile_country_code is not None:
            self.mobile_country_code = mobile_country_code
        if mobile_network_code is not None:
            self.mobile_network_code = mobile_network_code
        if phone_number_id is not None:
            self.phone_number_id = phone_number_id
        if failure_message is not None:
            self.failure_message = failure_message

    @property
    def id(self):
        """Gets the id of this PhoneProvisioningJobItemDto.  # noqa: E501


        :return: The id of this PhoneProvisioningJobItemDto.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this PhoneProvisioningJobItemDto.


        :param id: The id of this PhoneProvisioningJobItemDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def phone_number(self):
        """Gets the phone_number of this PhoneProvisioningJobItemDto.  # noqa: E501


        :return: The phone_number of this PhoneProvisioningJobItemDto.  # noqa: E501
        :rtype: str
        """
        return self._phone_number

    @phone_number.setter
    def phone_number(self, phone_number):
        """Sets the phone_number of this PhoneProvisioningJobItemDto.


        :param phone_number: The phone_number of this PhoneProvisioningJobItemDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and phone_number is None:  # noqa: E501
            raise ValueError("Invalid value for `phone_number`, must not be `None`")  # noqa: E501

        self._phone_number = phone_number

    @property
    def provider_label(self):
        """Gets the provider_label of this PhoneProvisioningJobItemDto.  # noqa: E501


        :return: The provider_label of this PhoneProvisioningJobItemDto.  # noqa: E501
        :rtype: str
        """
        return self._provider_label

    @provider_label.setter
    def provider_label(self, provider_label):
        """Sets the provider_label of this PhoneProvisioningJobItemDto.


        :param provider_label: The provider_label of this PhoneProvisioningJobItemDto.  # noqa: E501
        :type: str
        """

        self._provider_label = provider_label

    @property
    def status(self):
        """Gets the status of this PhoneProvisioningJobItemDto.  # noqa: E501


        :return: The status of this PhoneProvisioningJobItemDto.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this PhoneProvisioningJobItemDto.


        :param status: The status of this PhoneProvisioningJobItemDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and status is None:  # noqa: E501
            raise ValueError("Invalid value for `status`, must not be `None`")  # noqa: E501
        allowed_values = ["PENDING", "PROVISIONING", "PROVISIONED", "UNAVAILABLE", "FAILED"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and status not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}"  # noqa: E501
                .format(status, allowed_values)
            )

        self._status = status

    @property
    def line_type(self):
        """Gets the line_type of this PhoneProvisioningJobItemDto.  # noqa: E501


        :return: The line_type of this PhoneProvisioningJobItemDto.  # noqa: E501
        :rtype: str
        """
        return self._line_type

    @line_type.setter
    def line_type(self, line_type):
        """Sets the line_type of this PhoneProvisioningJobItemDto.


        :param line_type: The line_type of this PhoneProvisioningJobItemDto.  # noqa: E501
        :type: str
        """

        self._line_type = line_type

    @property
    def carrier_name(self):
        """Gets the carrier_name of this PhoneProvisioningJobItemDto.  # noqa: E501


        :return: The carrier_name of this PhoneProvisioningJobItemDto.  # noqa: E501
        :rtype: str
        """
        return self._carrier_name

    @carrier_name.setter
    def carrier_name(self, carrier_name):
        """Sets the carrier_name of this PhoneProvisioningJobItemDto.


        :param carrier_name: The carrier_name of this PhoneProvisioningJobItemDto.  # noqa: E501
        :type: str
        """

        self._carrier_name = carrier_name

    @property
    def mobile_country_code(self):
        """Gets the mobile_country_code of this PhoneProvisioningJobItemDto.  # noqa: E501


        :return: The mobile_country_code of this PhoneProvisioningJobItemDto.  # noqa: E501
        :rtype: str
        """
        return self._mobile_country_code

    @mobile_country_code.setter
    def mobile_country_code(self, mobile_country_code):
        """Sets the mobile_country_code of this PhoneProvisioningJobItemDto.


        :param mobile_country_code: The mobile_country_code of this PhoneProvisioningJobItemDto.  # noqa: E501
        :type: str
        """

        self._mobile_country_code = mobile_country_code

    @property
    def mobile_network_code(self):
        """Gets the mobile_network_code of this PhoneProvisioningJobItemDto.  # noqa: E501


        :return: The mobile_network_code of this PhoneProvisioningJobItemDto.  # noqa: E501
        :rtype: str
        """
        return self._mobile_network_code

    @mobile_network_code.setter
    def mobile_network_code(self, mobile_network_code):
        """Sets the mobile_network_code of this PhoneProvisioningJobItemDto.


        :param mobile_network_code: The mobile_network_code of this PhoneProvisioningJobItemDto.  # noqa: E501
        :type: str
        """

        self._mobile_network_code = mobile_network_code

    @property
    def phone_number_id(self):
        """Gets the phone_number_id of this PhoneProvisioningJobItemDto.  # noqa: E501


        :return: The phone_number_id of this PhoneProvisioningJobItemDto.  # noqa: E501
        :rtype: str
        """
        return self._phone_number_id

    @phone_number_id.setter
    def phone_number_id(self, phone_number_id):
        """Sets the phone_number_id of this PhoneProvisioningJobItemDto.


        :param phone_number_id: The phone_number_id of this PhoneProvisioningJobItemDto.  # noqa: E501
        :type: str
        """

        self._phone_number_id = phone_number_id

    @property
    def failure_message(self):
        """Gets the failure_message of this PhoneProvisioningJobItemDto.  # noqa: E501


        :return: The failure_message of this PhoneProvisioningJobItemDto.  # noqa: E501
        :rtype: str
        """
        return self._failure_message

    @failure_message.setter
    def failure_message(self, failure_message):
        """Sets the failure_message of this PhoneProvisioningJobItemDto.


        :param failure_message: The failure_message of this PhoneProvisioningJobItemDto.  # noqa: E501
        :type: str
        """

        self._failure_message = failure_message

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PhoneProvisioningJobItemDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PhoneProvisioningJobItemDto):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class CheckEmailAuditOptions(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'from_address': 'str',
        'recipient': 'str',
        'subject': 'str',
        'html_body': 'str',
        'text_body': 'str',
        'email_analysis': 'EmailAnalysis',
        'has_attachments': 'bool',
        'captcha_token': 'str'
    }

    attribute_map = {
        'from_address': 'fromAddress',
        'recipient': 'recipient',
        'subject': 'subject',
        'html_body': 'htmlBody',
        'text_body': 'textBody',
        'email_analysis': 'emailAnalysis',
        'has_attachments': 'hasAttachments',
        'captcha_token': 'captchaToken'
    }

    def __init__(self, from_address=None, recipient=None, subject=None, html_body=None, text_body=None, email_analysis=None, has_attachments=None, captcha_token=None, local_vars_configuration=None):  # noqa: E501
        """CheckEmailAuditOptions - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._from_address = None
        self._recipient = None
        self._subject = None
        self._html_body = None
        self._text_body = None
        self._email_analysis = None
        self._has_attachments = None
        self._captcha_token = None
        self.discriminator = None

        self.from_address = from_address
        self.recipient = recipient
        self.subject = subject
        self.html_body = html_body
        self.text_body = text_body
        self.email_analysis = email_analysis
        self.has_attachments = has_attachments
        self.captcha_token = captcha_token

    @property
    def from_address(self):
        """Gets the from_address of this CheckEmailAuditOptions.  # noqa: E501

        Optional sender address context  # noqa: E501

        :return: The from_address of this CheckEmailAuditOptions.  # noqa: E501
        :rtype: str
        """
        return self._from_address

    @from_address.setter
    def from_address(self, from_address):
        """Sets the from_address of this CheckEmailAuditOptions.

        Optional sender address context  # noqa: E501

        :param from_address: The from_address of this CheckEmailAuditOptions.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                from_address is not None and len(from_address) > 320):
            raise ValueError("Invalid value for `from_address`, length must be less than or equal to `320`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                from_address is not None and len(from_address) < 0):
            raise ValueError("Invalid value for `from_address`, length must be greater than or equal to `0`")  # noqa: E501

        self._from_address = from_address

    @property
    def recipient(self):
        """Gets the recipient of this CheckEmailAuditOptions.  # noqa: E501

        Optional recipient context  # noqa: E501

        :return: The recipient of this CheckEmailAuditOptions.  # noqa: E501
        :rtype: str
        """
        return self._recipient

    @recipient.setter
    def recipient(self, recipient):
        """Sets the recipient of this CheckEmailAuditOptions.

        Optional recipient context  # noqa: E501

        :param recipient: The recipient of this CheckEmailAuditOptions.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                recipient is not None and len(recipient) > 320):
            raise ValueError("Invalid value for `recipient`, length must be less than or equal to `320`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                recipient is not None and len(recipient) < 0):
            raise ValueError("Invalid value for `recipient`, length must be greater than or equal to `0`")  # noqa: E501

        self._recipient = recipient

    @property
    def subject(self):
        """Gets the subject of this CheckEmailAuditOptions.  # noqa: E501

        Optional subject line context  # noqa: E501

        :return: The subject of this CheckEmailAuditOptions.  # noqa: E501
        :rtype: str
        """
        return self._subject

    @subject.setter
    def subject(self, subject):
        """Sets the subject of this CheckEmailAuditOptions.

        Optional subject line context  # noqa: E501

        :param subject: The subject of this CheckEmailAuditOptions.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                subject is not None and len(subject) > 998):
            raise ValueError("Invalid value for `subject`, length must be less than or equal to `998`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                subject is not None and len(subject) < 0):
            raise ValueError("Invalid value for `subject`, length must be greater than or equal to `0`")  # noqa: E501

        self._subject = subject

    @property
    def html_body(self):
        """Gets the html_body of this CheckEmailAuditOptions.  # noqa: E501

        Optional HTML email body  # noqa: E501

        :return: The html_body of this CheckEmailAuditOptions.  # noqa: E501
        :rtype: str
        """
        return self._html_body

    @html_body.setter
    def html_body(self, html_body):
        """Sets the html_body of this CheckEmailAuditOptions.

        Optional HTML email body  # noqa: E501

        :param html_body: The html_body of this CheckEmailAuditOptions.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                html_body is not None and len(html_body) > 200000):
            raise ValueError("Invalid value for `html_body`, length must be less than or equal to `200000`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                html_body is not None and len(html_body) < 0):
            raise ValueError("Invalid value for `html_body`, length must be greater than or equal to `0`")  # noqa: E501

        self._html_body = html_body

    @property
    def text_body(self):
        """Gets the text_body of this CheckEmailAuditOptions.  # noqa: E501

        Optional text email body  # noqa: E501

        :return: The text_body of this CheckEmailAuditOptions.  # noqa: E501
        :rtype: str
        """
        return self._text_body

    @text_body.setter
    def text_body(self, text_body):
        """Sets the text_body of this CheckEmailAuditOptions.

        Optional text email body  # noqa: E501

        :param text_body: The text_body of this CheckEmailAuditOptions.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                text_body is not None and len(text_body) > 200000):
            raise ValueError("Invalid value for `text_body`, length must be less than or equal to `200000`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                text_body is not None and len(text_body) < 0):
            raise ValueError("Invalid value for `text_body`, length must be greater than or equal to `0`")  # noqa: E501

        self._text_body = text_body

    @property
    def email_analysis(self):
        """Gets the email_analysis of this CheckEmailAuditOptions.  # noqa: E501


        :return: The email_analysis of this CheckEmailAuditOptions.  # noqa: E501
        :rtype: EmailAnalysis
        """
        return self._email_analysis

    @email_analysis.setter
    def email_analysis(self, email_analysis):
        """Sets the email_analysis of this CheckEmailAuditOptions.


        :param email_analysis: The email_analysis of this CheckEmailAuditOptions.  # noqa: E501
        :type: EmailAnalysis
        """

        self._email_analysis = email_analysis

    @property
    def has_attachments(self):
        """Gets the has_attachments of this CheckEmailAuditOptions.  # noqa: E501

        Whether the source email included attachments  # noqa: E501

        :return: The has_attachments of this CheckEmailAuditOptions.  # noqa: E501
        :rtype: bool
        """
        return self._has_attachments

    @has_attachments.setter
    def has_attachments(self, has_attachments):
        """Sets the has_attachments of this CheckEmailAuditOptions.

        Whether the source email included attachments  # noqa: E501

        :param has_attachments: The has_attachments of this CheckEmailAuditOptions.  # noqa: E501
        :type: bool
        """

        self._has_attachments = has_attachments

    @property
    def captcha_token(self):
        """Gets the captcha_token of this CheckEmailAuditOptions.  # noqa: E501

        Optional captcha token for abuse protection  # noqa: E501

        :return: The captcha_token of this CheckEmailAuditOptions.  # noqa: E501
        :rtype: str
        """
        return self._captcha_token

    @captcha_token.setter
    def captcha_token(self, captcha_token):
        """Sets the captcha_token of this CheckEmailAuditOptions.

        Optional captcha token for abuse protection  # noqa: E501

        :param captcha_token: The captcha_token of this CheckEmailAuditOptions.  # noqa: E501
        :type: str
        """

        self._captcha_token = captcha_token

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CheckEmailAuditOptions):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CheckEmailAuditOptions):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import mailslurp_client
from mailslurp_client.api.consent_controller_api import ConsentControllerApi  # noqa: E501
from mailslurp_client.rest import ApiException


class TestConsentControllerApi(unittest.TestCase):
    """ConsentControllerApi unit test stubs"""

    def setUp(self):
        self.api = mailslurp_client.api.consent_controller_api.ConsentControllerApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_check_sending_consent_for_email_address(self):
        """Test case for check_sending_consent_for_email_address

        """
        pass

    def test_get_opt_in_identities(self):
        """Test case for get_opt_in_identities

        """
        pass

    def test_revoke_opt_in_consent_for_email_address(self):
        """Test case for revoke_opt_in_consent_for_email_address

        """
        pass

    def test_send_opt_in_consent_for_email_address(self):
        """Test case for send_opt_in_consent_for_email_address

        Send a verification code to a user once they have explicitly submitted their email address  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class EmailAuditAnalysisResult(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'status': 'str',
        'health_score': 'int',
        'total_checks': 'int',
        'passing_checks': 'int',
        'failing_checks': 'int',
        'detected_links': 'int',
        'checked_links': 'int',
        'detected_images': 'int',
        'checked_images': 'int',
        'link_issue_count': 'int',
        'image_issue_count': 'int',
        'spelling_issue_count': 'int',
        'broken_links': 'list[EmailAuditUrlIssue]',
        'broken_images': 'list[EmailAuditUrlIssue]',
        'spelling_issues': 'list[EmailAuditSpellingIssue]',
        'compatibility_warning_count': 'int',
        'compatibility_not_supported_count': 'int',
        'compatibility_unknown_count': 'int',
        'feature_support': 'EmailFeatureSupportResult',
        'html_error_count': 'int',
        'html_warning_count': 'int',
        'html_info_count': 'int',
        'html_validation': 'HTMLValidationResult',
        'reputation_failure_count': 'int',
        'attachment_mention_issue_count': 'int',
        'external_check_skipped_count': 'int',
        'insights': 'list[str]',
        'error_message': 'str'
    }

    attribute_map = {
        'status': 'status',
        'health_score': 'healthScore',
        'total_checks': 'totalChecks',
        'passing_checks': 'passingChecks',
        'failing_checks': 'failingChecks',
        'detected_links': 'detectedLinks',
        'checked_links': 'checkedLinks',
        'detected_images': 'detectedImages',
        'checked_images': 'checkedImages',
        'link_issue_count': 'linkIssueCount',
        'image_issue_count': 'imageIssueCount',
        'spelling_issue_count': 'spellingIssueCount',
        'broken_links': 'brokenLinks',
        'broken_images': 'brokenImages',
        'spelling_issues': 'spellingIssues',
        'compatibility_warning_count': 'compatibilityWarningCount',
        'compatibility_not_supported_count': 'compatibilityNotSupportedCount',
        'compatibility_unknown_count': 'compatibilityUnknownCount',
        'feature_support': 'featureSupport',
        'html_error_count': 'htmlErrorCount',
        'html_warning_count': 'htmlWarningCount',
        'html_info_count': 'htmlInfoCount',
        'html_validation': 'htmlValidation',
        'reputation_failure_count': 'reputationFailureCount',
        'attachment_mention_issue_count': 'attachmentMentionIssueCount',
        'external_check_skipped_count': 'externalCheckSkippedCount',
        'insights': 'insights',
        'error_message': 'errorMessage'
    }

    def __init__(self, status=None, health_score=None, total_checks=None, passing_checks=None, failing_checks=None, detected_links=None, checked_links=None, detected_images=None, checked_images=None, link_issue_count=None, image_issue_count=None, spelling_issue_count=None, broken_links=None, broken_images=None, spelling_issues=None, compatibility_warning_count=None, compatibility_not_supported_count=None, compatibility_unknown_count=None, feature_support=None, html_error_count=None, html_warning_count=None, html_info_count=None, html_validation=None, reputation_failure_count=None, attachment_mention_issue_count=None, external_check_skipped_count=None, insights=None, error_message=None, local_vars_configuration=None):  # noqa: E501
        """EmailAuditAnalysisResult - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._status = None
        self._health_score = None
        self._total_checks = None
        self._passing_checks = None
        self._failing_checks = None
        self._detected_links = None
        self._checked_links = None
        self._detected_images = None
        self._checked_images = None
        self._link_issue_count = None
        self._image_issue_count = None
        self._spelling_issue_count = None
        self._broken_links = None
        self._broken_images = None
        self._spelling_issues = None
        self._compatibility_warning_count = None
        self._compatibility_not_supported_count = None
        self._compatibility_unknown_count = None
        self._feature_support = None
        self._html_error_count = None
        self._html_warning_count = None
        self._html_info_count = None
        self._html_validation = None
        self._reputation_failure_count = None
        self._attachment_mention_issue_count = None
        self._external_check_skipped_count = None
        self._insights = None
        self._error_message = None
        self.discriminator = None

        self.status = status
        self.health_score = health_score
        self.total_checks = total_checks
        self.passing_checks = passing_checks
        self.failing_checks = failing_checks
        self.detected_links = detected_links
        self.checked_links = checked_links
        self.detected_images = detected_images
        self.checked_images = checked_images
        self.link_issue_count = link_issue_count
        self.image_issue_count = image_issue_count
        self.spelling_issue_count = spelling_issue_count
        self.broken_links = broken_links
        self.broken_images = broken_images
        self.spelling_issues = spelling_issues
        self.compatibility_warning_count = compatibility_warning_count
        self.compatibility_not_supported_count = compatibility_not_supported_count
        self.compatibility_unknown_count = compatibility_unknown_count
        if feature_support is not None:
            self.feature_support = feature_support
        self.html_error_count = html_error_count
        self.html_warning_count = html_warning_count
        self.html_info_count = html_info_count
        self.html_validation = html_validation
        self.reputation_failure_count = reputation_failure_count
        self.attachment_mention_issue_count = attachment_mention_issue_count
        self.external_check_skipped_count = external_check_skipped_count
        self.insights = insights
        self.error_message = error_message

    @property
    def status(self):
        """Gets the status of this EmailAuditAnalysisResult.  # noqa: E501

        Health status for a one-shot email audit  # noqa: E501

        :return: The status of this EmailAuditAnalysisResult.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this EmailAuditAnalysisResult.

        Health status for a one-shot email audit  # noqa: E501

        :param status: The status of this EmailAuditAnalysisResult.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and status is None:  # noqa: E501
            raise ValueError("Invalid value for `status`, must not be `None`")  # noqa: E501
        allowed_values = ["HEALTHY", "WARNING", "FAILED"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and status not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}"  # noqa: E501
                .format(status, allowed_values)
            )

        self._status = status

    @property
    def health_score(self):
        """Gets the health_score of this EmailAuditAnalysisResult.  # noqa: E501


        :return: The health_score of this EmailAuditAnalysisResult.  # noqa: E501
        :rtype: int
        """
        return self._health_score

    @health_score.setter
    def health_score(self, health_score):
        """Sets the health_score of this EmailAuditAnalysisResult.


        :param health_score: The health_score of this EmailAuditAnalysisResult.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and health_score is None:  # noqa: E501
            raise ValueError("Invalid value for `health_score`, must not be `None`")  # noqa: E501

        self._health_score = health_score

    @property
    def total_checks(self):
        """Gets the total_checks of this EmailAuditAnalysisResult.  # noqa: E501


        :return: The total_checks of this EmailAuditAnalysisResult.  # noqa: E501
        :rtype: int
        """
        return self._total_checks

    @total_checks.setter
    def total_checks(self, total_checks):
        """Sets the total_checks of this EmailAuditAnalysisResult.


        :param total_checks: The total_checks of this EmailAuditAnalysisResult.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and total_checks is None:  # noqa: E501
            raise ValueError("Invalid value for `total_checks`, must not be `None`")  # noqa: E501

        self._total_checks = total_checks

    @property
    def passing_checks(self):
        """Gets the passing_checks of this EmailAuditAnalysisResult.  # noqa: E501


        :return: The passing_checks of this EmailAuditAnalysisResult.  # noqa: E501
        :rtype: int
        """
        return self._passing_checks

    @passing_checks.setter
    def passing_checks(self, passing_checks):
        """Sets the passing_checks of this EmailAuditAnalysisResult.


        :param passing_checks: The passing_checks of this EmailAuditAnalysisResult.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and passing_checks is None:  # noqa: E501
            raise ValueError("Invalid value for `passing_checks`, must not be `None`")  # noqa: E501

        self._passing_checks = passing_checks

    @property
    def failing_checks(self):
        """Gets the failing_checks of this EmailAuditAnalysisResult.  # noqa: E501


        :return: The failing_checks of this EmailAuditAnalysisResult.  # noqa: E501
        :rtype: int
        """
        return self._failing_checks

    @failing_checks.setter
    def failing_checks(self, failing_checks):
        """Sets the failing_checks of this EmailAuditAnalysisResult.


        :param failing_checks: The failing_checks of this EmailAuditAnalysisResult.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and failing_checks is None:  # noqa: E501
            raise ValueError("Invalid value for `failing_checks`, must not be `None`")  # noqa: E501

        self._failing_checks = failing_checks

    @property
    def detected_links(self):
        """Gets the detected_links of this EmailAuditAnalysisResult.  # noqa: E501


        :return: The detected_links of this EmailAuditAnalysisResult.  # noqa: E501
        :rtype: int
        """
        return self._detected_links

    @detected_links.setter
    def detected_links(self, detected_links):
        """Sets the detected_links of this EmailAuditAnalysisResult.


        :param detected_links: The detected_links of this EmailAuditAnalysisResult.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and detected_links is None:  # noqa: E501
            raise ValueError("Invalid value for `detected_links`, must not be `None`")  # noqa: E501

        self._detected_links = detected_links

    @property
    def checked_links(self):
        """Gets the checked_links of this EmailAuditAnalysisResult.  # noqa: E501


        :return: The checked_links of this EmailAuditAnalysisResult.  # noqa: E501
        :rtype: int
        """
        return self._checked_links

    @checked_links.setter
    def checked_links(self, checked_links):
        """Sets the checked_links of this EmailAuditAnalysisResult.


        :param checked_links: The checked_links of this EmailAuditAnalysisResult.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and checked_links is None:  # noqa: E501
            raise ValueError("Invalid value for `checked_links`, must not be `None`")  # noqa: E501

        self._checked_links = checked_links

    @property
    def detected_images(self):
        """Gets the detected_images of this EmailAuditAnalysisResult.  # noqa: E501


        :return: The detected_images of this EmailAuditAnalysisResult.  # noqa: E501
        :rtype: int
        """
        return self._detected_images

    @detected_images.setter
    def detected_images(self, detected_images):
        """Sets the detected_images of this EmailAuditAnalysisResult.


        :param detected_images: The detected_images of this EmailAuditAnalysisResult.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and detected_images is None:  # noqa: E501
            raise ValueError("Invalid value for `detected_images`, must not be `None`")  # noqa: E501

        self._detected_images = detected_images

    @property
    def checked_images(self):
        """Gets the checked_images of this EmailAuditAnalysisResult.  # noqa: E501


        :return: The checked_images of this EmailAuditAnalysisResult.  # noqa: E501
        :rtype: int
        """
        return self._checked_images

    @checked_images.setter
    def checked_images(self, checked_images):
        """Sets the checked_images of this EmailAuditAnalysisResult.


        :param checked_images: The checked_images of this EmailAuditAnalysisResult.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and checked_images is None:  # noqa: E501
            raise ValueError("Invalid value for `checked_images`, must not be `None`")  # noqa: E501

        self._checked_images = checked_images

    @property
    def link_issue_count(self):
        """Gets the link_issue_count of this EmailAuditAnalysisResult.  # noqa: E501


        :return: The link_issue_count of this EmailAuditAnalysisResult.  # noqa: E501
        :rtype: int
        """
        return self._link_issue_count

    @link_issue_count.setter
    def link_issue_count(self, link_issue_count):
        """Sets the link_issue_count of this EmailAuditAnalysisResult.


        :param link_issue_count: The link_issue_count of this EmailAuditAnalysisResult.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and link_issue_count is None:  # noqa: E501
            raise ValueError("Invalid value for `link_issue_count`, must not be `None`")  # noqa: E501

        self._link_issue_count = link_issue_count

    @property
    def image_issue_count(self):
        """Gets the image_issue_count of this EmailAuditAnalysisResult.  # noqa: E501


        :return: The image_issue_count of this EmailAuditAnalysisResult.  # noqa: E501
        :rtype: int
        """
        return self._image_issue_count

    @image_issue_count.setter
    def image_issue_count(self, image_issue_count):
        """Sets the image_issue_count of this EmailAuditAnalysisResult.


        :param image_issue_count: The image_issue_count of this EmailAuditAnalysisResult.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and image_issue_count is None:  # noqa: E501
            raise ValueError("Invalid value for `image_issue_count`, must not be `None`")  # noqa: E501

        self._image_issue_count = image_issue_count

    @property
    def spelling_issue_count(self):
        """Gets the spelling_issue_count of this EmailAuditAnalysisResult.  # noqa: E501


        :return: The spelling_issue_count of this EmailAuditAnalysisResult.  # noqa: E501
        :rtype: int
        """
        return self._spelling_issue_count

    @spelling_issue_count.setter
    def spelling_issue_count(self, spelling_issue_count):
        """Sets the spelling_issue_count of this EmailAuditAnalysisResult.


        :param spelling_issue_count: The spelling_issue_count of this EmailAuditAnalysisResult.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and spelling_issue_count is None:  # noqa: E501
            raise ValueError("Invalid value for `spelling_issue_count`, must not be `None`")  # noqa: E501

        self._spelling_issue_count = spelling_issue_count

    @property
    def broken_links(self):
        """Gets the broken_links of this EmailAuditAnalysisResult.  # noqa: E501


        :return: The broken_links of this EmailAuditAnalysisResult.  # noqa: E501
        :rtype: list[EmailAuditUrlIssue]
        """
        return self._broken_links

    @broken_links.setter
    def broken_links(self, broken_links):
        """Sets the broken_links of this EmailAuditAnalysisResult.


        :param broken_links: The broken_links of this EmailAuditAnalysisResult.  # noqa: E501
        :type: list[EmailAuditUrlIssue]
        """
        if self.local_vars_configuration.client_side_validation and broken_links is None:  # noqa: E501
            raise ValueError("Invalid value for `broken_links`, must not be `None`")  # noqa: E501

        self._broken_links = broken_links

    @property
    def broken_images(self):
        """Gets the broken_images of this EmailAuditAnalysisResult.  # noqa: E501


        :return: The broken_images of this EmailAuditAnalysisResult.  # noqa: E501
        :rtype: list[EmailAuditUrlIssue]
        """
        return self._broken_images

    @broken_images.setter
    def broken_images(self, broken_images):
        """Sets the broken_images of this EmailAuditAnalysisResult.


        :param broken_images: The broken_images of this EmailAuditAnalysisResult.  # noqa: E501
        :type: list[EmailAuditUrlIssue]
        """
        if self.local_vars_configuration.client_side_validation and broken_images is None:  # noqa: E501
            raise ValueError("Invalid value for `broken_images`, must not be `None`")  # noqa: E501

        self._broken_images = broken_images

    @property
    def spelling_issues(self):
        """Gets the spelling_issues of this EmailAuditAnalysisResult.  # noqa: E501


        :return: The spelling_issues of this EmailAuditAnalysisResult.  # noqa: E501
        :rtype: list[EmailAuditSpellingIssue]
        """
        return self._spelling_issues

    @spelling_issues.setter
    def spelling_issues(self, spelling_issues):
        """Sets the spelling_issues of this EmailAuditAnalysisResult.


        :param spelling_issues: The spelling_issues of this EmailAuditAnalysisResult.  # noqa: E501
        :type: list[EmailAuditSpellingIssue]
        """
        if self.local_vars_configuration.client_side_validation and spelling_issues is None:  # noqa: E501
            raise ValueError("Invalid value for `spelling_issues`, must not be `None`")  # noqa: E501

        self._spelling_issues = spelling_issues

    @property
    def compatibility_warning_count(self):
        """Gets the compatibility_warning_count of this EmailAuditAnalysisResult.  # noqa: E501


        :return: The compatibility_warning_count of this EmailAuditAnalysisResult.  # noqa: E501
        :rtype: int
        """
        return self._compatibility_warning_count

    @compatibility_warning_count.setter
    def compatibility_warning_count(self, compatibility_warning_count):
        """Sets the compatibility_warning_count of this EmailAuditAnalysisResult.


        :param compatibility_warning_count: The compatibility_warning_count of this EmailAuditAnalysisResult.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and compatibility_warning_count is None:  # noqa: E501
            raise ValueError("Invalid value for `compatibility_warning_count`, must not be `None`")  # noqa: E501

        self._compatibility_warning_count = compatibility_warning_count

    @property
    def compatibility_not_supported_count(self):
        """Gets the compatibility_not_supported_count of this EmailAuditAnalysisResult.  # noqa: E501


        :return: The compatibility_not_supported_count of this EmailAuditAnalysisResult.  # noqa: E501
        :rtype: int
        """
        return self._compatibility_not_supported_count

    @compatibility_not_supported_count.setter
    def compatibility_not_supported_count(self, compatibility_not_supported_count):
        """Sets the compatibility_not_supported_count of this EmailAuditAnalysisResult.


        :param compatibility_not_supported_count: The compatibility_not_supported_count of this EmailAuditAnalysisResult.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and compatibility_not_supported_count is None:  # noqa: E501
            raise ValueError("Invalid value for `compatibility_not_supported_count`, must not be `None`")  # noqa: E501

        self._compatibility_not_supported_count = compatibility_not_supported_count

    @property
    def compatibility_unknown_count(self):
        """Gets the compatibility_unknown_count of this EmailAuditAnalysisResult.  # noqa: E501


        :return: The compatibility_unknown_count of this EmailAuditAnalysisResult.  # noqa: E501
        :rtype: int
        """
        return self._compatibility_unknown_count

    @compatibility_unknown_count.setter
    def compatibility_unknown_count(self, compatibility_unknown_count):
        """Sets the compatibility_unknown_count of this EmailAuditAnalysisResult.


        :param compatibility_unknown_count: The compatibility_unknown_count of this EmailAuditAnalysisResult.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and compatibility_unknown_count is None:  # noqa: E501
            raise ValueError("Invalid value for `compatibility_unknown_count`, must not be `None`")  # noqa: E501

        self._compatibility_unknown_count = compatibility_unknown_count

    @property
    def feature_support(self):
        """Gets the feature_support of this EmailAuditAnalysisResult.  # noqa: E501


        :return: The feature_support of this EmailAuditAnalysisResult.  # noqa: E501
        :rtype: EmailFeatureSupportResult
        """
        return self._feature_support

    @feature_support.setter
    def feature_support(self, feature_support):
        """Sets the feature_support of this EmailAuditAnalysisResult.


        :param feature_support: The feature_support of this EmailAuditAnalysisResult.  # noqa: E501
        :type: EmailFeatureSupportResult
        """

        self._feature_support = feature_support

    @property
    def html_error_count(self):
        """Gets the html_error_count of this EmailAuditAnalysisResult.  # noqa: E501


        :return: The html_error_count of this EmailAuditAnalysisResult.  # noqa: E501
        :rtype: int
        """
        return self._html_error_count

    @html_error_count.setter
    def html_error_count(self, html_error_count):
        """Sets the html_error_count of this EmailAuditAnalysisResult.


        :param html_error_count: The html_error_count of this EmailAuditAnalysisResult.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and html_error_count is None:  # noqa: E501
            raise ValueError("Invalid value for `html_error_count`, must not be `None`")  # noqa: E501

        self._html_error_count = html_error_count

    @property
    def html_warning_count(self):
        """Gets the html_warning_count of this EmailAuditAnalysisResult.  # noqa: E501


        :return: The html_warning_count of this EmailAuditAnalysisResult.  # noqa: E501
        :rtype: int
        """
        return self._html_warning_count

    @html_warning_count.setter
    def html_warning_count(self, html_warning_count):
        """Sets the html_warning_count of this EmailAuditAnalysisResult.


        :param html_warning_count: The html_warning_count of this EmailAuditAnalysisResult.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and html_warning_count is None:  # noqa: E501
            raise ValueError("Invalid value for `html_warning_count`, must not be `None`")  # noqa: E501

        self._html_warning_count = html_warning_count

    @property
    def html_info_count(self):
        """Gets the html_info_count of this EmailAuditAnalysisResult.  # noqa: E501


        :return: The html_info_count of this EmailAuditAnalysisResult.  # noqa: E501
        :rtype: int
        """
        return self._html_info_count

    @html_info_count.setter
    def html_info_count(self, html_info_count):
        """Sets the html_info_count of this EmailAuditAnalysisResult.


        :param html_info_count: The html_info_count of this EmailAuditAnalysisResult.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and html_info_count is None:  # noqa: E501
            raise ValueError("Invalid value for `html_info_count`, must not be `None`")  # noqa: E501

        self._html_info_count = html_info_count

    @property
    def html_validation(self):
        """Gets the html_validation of this EmailAuditAnalysisResult.  # noqa: E501


        :return: The html_validation of this EmailAuditAnalysisResult.  # noqa: E501
        :rtype: HTMLValidationResult
        """
        return self._html_validation

    @html_validation.setter
    def html_validation(self, html_validation):
        """Sets the html_validation of this EmailAuditAnalysisResult.


        :param html_validation: The html_validation of this EmailAuditAnalysisResult.  # noqa: E501
        :type: HTMLValidationResult
        """

        self._html_validation = html_validation

    @property
    def reputation_failure_count(self):
        """Gets the reputation_failure_count of this EmailAuditAnalysisResult.  # noqa: E501


        :return: The reputation_failure_count of this EmailAuditAnalysisResult.  # noqa: E501
        :rtype: int
        """
        return self._reputation_failure_count

    @reputation_failure_count.setter
    def reputation_failure_count(self, reputation_failure_count):
        """Sets the reputation_failure_count of this EmailAuditAnalysisResult.


        :param reputation_failure_count: The reputation_failure_count of this EmailAuditAnalysisResult.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and reputation_failure_count is None:  # noqa: E501
            raise ValueError("Invalid value for `reputation_failure_count`, must not be `None`")  # noqa: E501

        self._reputation_failure_count = reputation_failure_count

    @property
    def attachment_mention_issue_count(self):
        """Gets the attachment_mention_issue_count of this EmailAuditAnalysisResult.  # noqa: E501


        :return: The attachment_mention_issue_count of this EmailAuditAnalysisResult.  # noqa: E501
        :rtype: int
        """
        return self._attachment_mention_issue_count

    @attachment_mention_issue_count.setter
    def attachment_mention_issue_count(self, attachment_mention_issue_count):
        """Sets the attachment_mention_issue_count of this EmailAuditAnalysisResult.


        :param attachment_mention_issue_count: The attachment_mention_issue_count of this EmailAuditAnalysisResult.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and attachment_mention_issue_count is None:  # noqa: E501
            raise ValueError("Invalid value for `attachment_mention_issue_count`, must not be `None`")  # noqa: E501

        self._attachment_mention_issue_count = attachment_mention_issue_count

    @property
    def external_check_skipped_count(self):
        """Gets the external_check_skipped_count of this EmailAuditAnalysisResult.  # noqa: E501


        :return: The external_check_skipped_count of this EmailAuditAnalysisResult.  # noqa: E501
        :rtype: int
        """
        return self._external_check_skipped_count

    @external_check_skipped_count.setter
    def external_check_skipped_count(self, external_check_skipped_count):
        """Sets the external_check_skipped_count of this EmailAuditAnalysisResult.


        :param external_check_skipped_count: The external_check_skipped_count of this EmailAuditAnalysisResult.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and external_check_skipped_count is None:  # noqa: E501
            raise ValueError("Invalid value for `external_check_skipped_count`, must not be `None`")  # noqa: E501

        self._external_check_skipped_count = external_check_skipped_count

    @property
    def insights(self):
        """Gets the insights of this EmailAuditAnalysisResult.  # noqa: E501


        :return: The insights of this EmailAuditAnalysisResult.  # noqa: E501
        :rtype: list[str]
        """
        return self._insights

    @insights.setter
    def insights(self, insights):
        """Sets the insights of this EmailAuditAnalysisResult.


        :param insights: The insights of this EmailAuditAnalysisResult.  # noqa: E501
        :type: list[str]
        """
        if self.local_vars_configuration.client_side_validation and insights is None:  # noqa: E501
            raise ValueError("Invalid value for `insights`, must not be `None`")  # noqa: E501

        self._insights = insights

    @property
    def error_message(self):
        """Gets the error_message of this EmailAuditAnalysisResult.  # noqa: E501


        :return: The error_message of this EmailAuditAnalysisResult.  # noqa: E501
        :rtype: str
        """
        return self._error_message

    @error_message.setter
    def error_message(self, error_message):
        """Sets the error_message of this EmailAuditAnalysisResult.


        :param error_message: The error_message of this EmailAuditAnalysisResult.  # noqa: E501
        :type: str
        """

        self._error_message = error_message

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EmailAuditAnalysisResult):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, EmailAuditAnalysisResult):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class AuditLogSearchOptions(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'since': 'datetime',
        'before': 'datetime',
        'action': 'str',
        'user_id': 'str',
        'actor_user_id': 'str',
        'target_user_id': 'str',
        'resource_type': 'str',
        'resource_id': 'str',
        'outcome': 'str',
        'request_id': 'str',
        'ip_address': 'str',
        'event_id': 'str',
        'page_size': 'int',
        'cursor': 'str'
    }

    attribute_map = {
        'since': 'since',
        'before': 'before',
        'action': 'action',
        'user_id': 'userId',
        'actor_user_id': 'actorUserId',
        'target_user_id': 'targetUserId',
        'resource_type': 'resourceType',
        'resource_id': 'resourceId',
        'outcome': 'outcome',
        'request_id': 'requestId',
        'ip_address': 'ipAddress',
        'event_id': 'eventId',
        'page_size': 'pageSize',
        'cursor': 'cursor'
    }

    def __init__(self, since=None, before=None, action=None, user_id=None, actor_user_id=None, target_user_id=None, resource_type=None, resource_id=None, outcome=None, request_id=None, ip_address=None, event_id=None, page_size=None, cursor=None, local_vars_configuration=None):  # noqa: E501
        """AuditLogSearchOptions - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._since = None
        self._before = None
        self._action = None
        self._user_id = None
        self._actor_user_id = None
        self._target_user_id = None
        self._resource_type = None
        self._resource_id = None
        self._outcome = None
        self._request_id = None
        self._ip_address = None
        self._event_id = None
        self._page_size = None
        self._cursor = None
        self.discriminator = None

        if since is not None:
            self.since = since
        if before is not None:
            self.before = before
        if action is not None:
            self.action = action
        if user_id is not None:
            self.user_id = user_id
        if actor_user_id is not None:
            self.actor_user_id = actor_user_id
        if target_user_id is not None:
            self.target_user_id = target_user_id
        if resource_type is not None:
            self.resource_type = resource_type
        if resource_id is not None:
            self.resource_id = resource_id
        if outcome is not None:
            self.outcome = outcome
        if request_id is not None:
            self.request_id = request_id
        if ip_address is not None:
            self.ip_address = ip_address
        if event_id is not None:
            self.event_id = event_id
        if page_size is not None:
            self.page_size = page_size
        if cursor is not None:
            self.cursor = cursor

    @property
    def since(self):
        """Gets the since of this AuditLogSearchOptions.  # noqa: E501


        :return: The since of this AuditLogSearchOptions.  # noqa: E501
        :rtype: datetime
        """
        return self._since

    @since.setter
    def since(self, since):
        """Sets the since of this AuditLogSearchOptions.


        :param since: The since of this AuditLogSearchOptions.  # noqa: E501
        :type: datetime
        """

        self._since = since

    @property
    def before(self):
        """Gets the before of this AuditLogSearchOptions.  # noqa: E501


        :return: The before of this AuditLogSearchOptions.  # noqa: E501
        :rtype: datetime
        """
        return self._before

    @before.setter
    def before(self, before):
        """Sets the before of this AuditLogSearchOptions.


        :param before: The before of this AuditLogSearchOptions.  # noqa: E501
        :type: datetime
        """

        self._before = before

    @property
    def action(self):
        """Gets the action of this AuditLogSearchOptions.  # noqa: E501


        :return: The action of this AuditLogSearchOptions.  # noqa: E501
        :rtype: str
        """
        return self._action

    @action.setter
    def action(self, action):
        """Sets the action of this AuditLogSearchOptions.


        :param action: The action of this AuditLogSearchOptions.  # noqa: E501
        :type: str
        """

        self._action = action

    @property
    def user_id(self):
        """Gets the user_id of this AuditLogSearchOptions.  # noqa: E501


        :return: The user_id of this AuditLogSearchOptions.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this AuditLogSearchOptions.


        :param user_id: The user_id of this AuditLogSearchOptions.  # noqa: E501
        :type: str
        """

        self._user_id = user_id

    @property
    def actor_user_id(self):
        """Gets the actor_user_id of this AuditLogSearchOptions.  # noqa: E501


        :return: The actor_user_id of this AuditLogSearchOptions.  # noqa: E501
        :rtype: str
        """
        return self._actor_user_id

    @actor_user_id.setter
    def actor_user_id(self, actor_user_id):
        """Sets the actor_user_id of this AuditLogSearchOptions.


        :param actor_user_id: The actor_user_id of this AuditLogSearchOptions.  # noqa: E501
        :type: str
        """

        self._actor_user_id = actor_user_id

    @property
    def target_user_id(self):
        """Gets the target_user_id of this AuditLogSearchOptions.  # noqa: E501


        :return: The target_user_id of this AuditLogSearchOptions.  # noqa: E501
        :rtype: str
        """
        return self._target_user_id

    @target_user_id.setter
    def target_user_id(self, target_user_id):
        """Sets the target_user_id of this AuditLogSearchOptions.


        :param target_user_id: The target_user_id of this AuditLogSearchOptions.  # noqa: E501
        :type: str
        """

        self._target_user_id = target_user_id

    @property
    def resource_type(self):
        """Gets the resource_type of this AuditLogSearchOptions.  # noqa: E501


        :return: The resource_type of this AuditLogSearchOptions.  # noqa: E501
        :rtype: str
        """
        return self._resource_type

    @resource_type.setter
    def resource_type(self, resource_type):
        """Sets the resource_type of this AuditLogSearchOptions.


        :param resource_type: The resource_type of this AuditLogSearchOptions.  # noqa: E501
        :type: str
        """

        self._resource_type = resource_type

    @property
    def resource_id(self):
        """Gets the resource_id of this AuditLogSearchOptions.  # noqa: E501


        :return: The resource_id of this AuditLogSearchOptions.  # noqa: E501
        :rtype: str
        """
        return self._resource_id

    @resource_id.setter
    def resource_id(self, resource_id):
        """Sets the resource_id of this AuditLogSearchOptions.


        :param resource_id: The resource_id of this AuditLogSearchOptions.  # noqa: E501
        :type: str
        """

        self._resource_id = resource_id

    @property
    def outcome(self):
        """Gets the outcome of this AuditLogSearchOptions.  # noqa: E501


        :return: The outcome of this AuditLogSearchOptions.  # noqa: E501
        :rtype: str
        """
        return self._outcome

    @outcome.setter
    def outcome(self, outcome):
        """Sets the outcome of this AuditLogSearchOptions.


        :param outcome: The outcome of this AuditLogSearchOptions.  # noqa: E501
        :type: str
        """

        self._outcome = outcome

    @property
    def request_id(self):
        """Gets the request_id of this AuditLogSearchOptions.  # noqa: E501


        :return: The request_id of this AuditLogSearchOptions.  # noqa: E501
        :rtype: str
        """
        return self._request_id

    @request_id.setter
    def request_id(self, request_id):
        """Sets the request_id of this AuditLogSearchOptions.


        :param request_id: The request_id of this AuditLogSearchOptions.  # noqa: E501
        :type: str
        """

        self._request_id = request_id

    @property
    def ip_address(self):
        """Gets the ip_address of this AuditLogSearchOptions.  # noqa: E501


        :return: The ip_address of this AuditLogSearchOptions.  # noqa: E501
        :rtype: str
        """
        return self._ip_address

    @ip_address.setter
    def ip_address(self, ip_address):
        """Sets the ip_address of this AuditLogSearchOptions.


        :param ip_address: The ip_address of this AuditLogSearchOptions.  # noqa: E501
        :type: str
        """

        self._ip_address = ip_address

    @property
    def event_id(self):
        """Gets the event_id of this AuditLogSearchOptions.  # noqa: E501


        :return: The event_id of this AuditLogSearchOptions.  # noqa: E501
        :rtype: str
        """
        return self._event_id

    @event_id.setter
    def event_id(self, event_id):
        """Sets the event_id of this AuditLogSearchOptions.


        :param event_id: The event_id of this AuditLogSearchOptions.  # noqa: E501
        :type: str
        """

        self._event_id = event_id

    @property
    def page_size(self):
        """Gets the page_size of this AuditLogSearchOptions.  # noqa: E501


        :return: The page_size of this AuditLogSearchOptions.  # noqa: E501
        :rtype: int
        """
        return self._page_size

    @page_size.setter
    def page_size(self, page_size):
        """Sets the page_size of this AuditLogSearchOptions.


        :param page_size: The page_size of this AuditLogSearchOptions.  # noqa: E501
        :type: int
        """

        self._page_size = page_size

    @property
    def cursor(self):
        """Gets the cursor of this AuditLogSearchOptions.  # noqa: E501


        :return: The cursor of this AuditLogSearchOptions.  # noqa: E501
        :rtype: str
        """
        return self._cursor

    @cursor.setter
    def cursor(self, cursor):
        """Sets the cursor of this AuditLogSearchOptions.


        :param cursor: The cursor of this AuditLogSearchOptions.  # noqa: E501
        :type: str
        """

        self._cursor = cursor

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AuditLogSearchOptions):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AuditLogSearchOptions):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class SearchInboxesOptions(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'page_index': 'int',
        'page_size': 'int',
        'sort_direction': 'str',
        'favourite': 'bool',
        'search': 'str',
        'tag': 'str',
        'since': 'datetime',
        'before': 'datetime',
        'inbox_type': 'str',
        'inbox_function': 'str',
        'domain_id': 'str'
    }

    attribute_map = {
        'page_index': 'pageIndex',
        'page_size': 'pageSize',
        'sort_direction': 'sortDirection',
        'favourite': 'favourite',
        'search': 'search',
        'tag': 'tag',
        'since': 'since',
        'before': 'before',
        'inbox_type': 'inboxType',
        'inbox_function': 'inboxFunction',
        'domain_id': 'domainId'
    }

    def __init__(self, page_index=None, page_size=None, sort_direction=None, favourite=None, search=None, tag=None, since=None, before=None, inbox_type=None, inbox_function=None, domain_id=None, local_vars_configuration=None):  # noqa: E501
        """SearchInboxesOptions - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._page_index = None
        self._page_size = None
        self._sort_direction = None
        self._favourite = None
        self._search = None
        self._tag = None
        self._since = None
        self._before = None
        self._inbox_type = None
        self._inbox_function = None
        self._domain_id = None
        self.discriminator = None

        self.page_index = page_index
        self.page_size = page_size
        self.sort_direction = sort_direction
        self.favourite = favourite
        self.search = search
        self.tag = tag
        self.since = since
        self.before = before
        self.inbox_type = inbox_type
        self.inbox_function = inbox_function
        self.domain_id = domain_id

    @property
    def page_index(self):
        """Gets the page_index of this SearchInboxesOptions.  # noqa: E501

        Optional page index in list pagination  # noqa: E501

        :return: The page_index of this SearchInboxesOptions.  # noqa: E501
        :rtype: int
        """
        return self._page_index

    @page_index.setter
    def page_index(self, page_index):
        """Sets the page_index of this SearchInboxesOptions.

        Optional page index in list pagination  # noqa: E501

        :param page_index: The page_index of this SearchInboxesOptions.  # noqa: E501
        :type: int
        """

        self._page_index = page_index

    @property
    def page_size(self):
        """Gets the page_size of this SearchInboxesOptions.  # noqa: E501

        Optional page size in list pagination  # noqa: E501

        :return: The page_size of this SearchInboxesOptions.  # noqa: E501
        :rtype: int
        """
        return self._page_size

    @page_size.setter
    def page_size(self, page_size):
        """Sets the page_size of this SearchInboxesOptions.

        Optional page size in list pagination  # noqa: E501

        :param page_size: The page_size of this SearchInboxesOptions.  # noqa: E501
        :type: int
        """

        self._page_size = page_size

    @property
    def sort_direction(self):
        """Gets the sort_direction of this SearchInboxesOptions.  # noqa: E501

        Optional createdAt sort direction ASC or DESC  # noqa: E501

        :return: The sort_direction of this SearchInboxesOptions.  # noqa: E501
        :rtype: str
        """
        return self._sort_direction

    @sort_direction.setter
    def sort_direction(self, sort_direction):
        """Sets the sort_direction of this SearchInboxesOptions.

        Optional createdAt sort direction ASC or DESC  # noqa: E501

        :param sort_direction: The sort_direction of this SearchInboxesOptions.  # noqa: E501
        :type: str
        """
        allowed_values = [None,"ASC", "DESC"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and sort_direction not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `sort_direction` ({0}), must be one of {1}"  # noqa: E501
                .format(sort_direction, allowed_values)
            )

        self._sort_direction = sort_direction

    @property
    def favourite(self):
        """Gets the favourite of this SearchInboxesOptions.  # noqa: E501

        Optionally filter results for favourites only  # noqa: E501

        :return: The favourite of this SearchInboxesOptions.  # noqa: E501
        :rtype: bool
        """
        return self._favourite

    @favourite.setter
    def favourite(self, favourite):
        """Sets the favourite of this SearchInboxesOptions.

        Optionally filter results for favourites only  # noqa: E501

        :param favourite: The favourite of this SearchInboxesOptions.  # noqa: E501
        :type: bool
        """

        self._favourite = favourite

    @property
    def search(self):
        """Gets the search of this SearchInboxesOptions.  # noqa: E501

        Optionally filter by search words partial matching name and email address  # noqa: E501

        :return: The search of this SearchInboxesOptions.  # noqa: E501
        :rtype: str
        """
        return self._search

    @search.setter
    def search(self, search):
        """Sets the search of this SearchInboxesOptions.

        Optionally filter by search words partial matching name and email address  # noqa: E501

        :param search: The search of this SearchInboxesOptions.  # noqa: E501
        :type: str
        """

        self._search = search

    @property
    def tag(self):
        """Gets the tag of this SearchInboxesOptions.  # noqa: E501

        Optionally filter by tags. Will return inboxes that include given tags  # noqa: E501

        :return: The tag of this SearchInboxesOptions.  # noqa: E501
        :rtype: str
        """
        return self._tag

    @tag.setter
    def tag(self, tag):
        """Sets the tag of this SearchInboxesOptions.

        Optionally filter by tags. Will return inboxes that include given tags  # noqa: E501

        :param tag: The tag of this SearchInboxesOptions.  # noqa: E501
        :type: str
        """

        self._tag = tag

    @property
    def since(self):
        """Gets the since of this SearchInboxesOptions.  # noqa: E501

        Optional filter by created after given date time  # noqa: E501

        :return: The since of this SearchInboxesOptions.  # noqa: E501
        :rtype: datetime
        """
        return self._since

    @since.setter
    def since(self, since):
        """Sets the since of this SearchInboxesOptions.

        Optional filter by created after given date time  # noqa: E501

        :param since: The since of this SearchInboxesOptions.  # noqa: E501
        :type: datetime
        """

        self._since = since

    @property
    def before(self):
        """Gets the before of this SearchInboxesOptions.  # noqa: E501

        Optional filter by created before given date time  # noqa: E501

        :return: The before of this SearchInboxesOptions.  # noqa: E501
        :rtype: datetime
        """
        return self._before

    @before.setter
    def before(self, before):
        """Sets the before of this SearchInboxesOptions.

        Optional filter by created before given date time  # noqa: E501

        :param before: The before of this SearchInboxesOptions.  # noqa: E501
        :type: datetime
        """

        self._before = before

    @property
    def inbox_type(self):
        """Gets the inbox_type of this SearchInboxesOptions.  # noqa: E501

        Type of inbox. HTTP inboxes are faster and better for most cases. SMTP inboxes are more suited for public facing inbound messages (but cannot send).  # noqa: E501

        :return: The inbox_type of this SearchInboxesOptions.  # noqa: E501
        :rtype: str
        """
        return self._inbox_type

    @inbox_type.setter
    def inbox_type(self, inbox_type):
        """Sets the inbox_type of this SearchInboxesOptions.

        Type of inbox. HTTP inboxes are faster and better for most cases. SMTP inboxes are more suited for public facing inbound messages (but cannot send).  # noqa: E501

        :param inbox_type: The inbox_type of this SearchInboxesOptions.  # noqa: E501
        :type: str
        """
        allowed_values = [None,"HTTP_INBOX", "SMTP_INBOX"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and inbox_type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `inbox_type` ({0}), must be one of {1}"  # noqa: E501
                .format(inbox_type, allowed_values)
            )

        self._inbox_type = inbox_type

    @property
    def inbox_function(self):
        """Gets the inbox_function of this SearchInboxesOptions.  # noqa: E501

        Optional filter by inbox function  # noqa: E501

        :return: The inbox_function of this SearchInboxesOptions.  # noqa: E501
        :rtype: str
        """
        return self._inbox_function

    @inbox_function.setter
    def inbox_function(self, inbox_function):
        """Sets the inbox_function of this SearchInboxesOptions.

        Optional filter by inbox function  # noqa: E501

        :param inbox_function: The inbox_function of this SearchInboxesOptions.  # noqa: E501
        :type: str
        """
        allowed_values = [None,"ALIAS", "THREAD", "CATCH_ALL", "CONNECTOR", "ACCOUNT", "GUEST", "OAUTH_CONNECTION_GMAIL"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and inbox_function not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `inbox_function` ({0}), must be one of {1}"  # noqa: E501
                .format(inbox_function, allowed_values)
            )

        self._inbox_function = inbox_function

    @property
    def domain_id(self):
        """Gets the domain_id of this SearchInboxesOptions.  # noqa: E501

        Optional domain ID filter  # noqa: E501

        :return: The domain_id of this SearchInboxesOptions.  # noqa: E501
        :rtype: str
        """
        return self._domain_id

    @domain_id.setter
    def domain_id(self, domain_id):
        """Sets the domain_id of this SearchInboxesOptions.

        Optional domain ID filter  # noqa: E501

        :param domain_id: The domain_id of this SearchInboxesOptions.  # noqa: E501
        :type: str
        """

        self._domain_id = domain_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SearchInboxesOptions):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SearchInboxesOptions):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class InlineObject1(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'to': 'str',
        'subject': 'str',
        'email_address': 'str',
        'success_message': 'str',
        'spam_check': 'str',
        'other_parameters': 'str'
    }

    attribute_map = {
        'to': '_to',
        'subject': '_subject',
        'email_address': '_emailAddress',
        'success_message': '_successMessage',
        'spam_check': '_spamCheck',
        'other_parameters': 'otherParameters'
    }

    def __init__(self, to=None, subject=None, email_address=None, success_message=None, spam_check=None, other_parameters=None, local_vars_configuration=None):  # noqa: E501
        """InlineObject1 - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._to = None
        self._subject = None
        self._email_address = None
        self._success_message = None
        self._spam_check = None
        self._other_parameters = None
        self.discriminator = None

        if to is not None:
            self.to = to
        if subject is not None:
            self.subject = subject
        if email_address is not None:
            self.email_address = email_address
        if success_message is not None:
            self.success_message = success_message
        if spam_check is not None:
            self.spam_check = spam_check
        if other_parameters is not None:
            self.other_parameters = other_parameters

    @property
    def to(self):
        """Gets the to of this InlineObject1.  # noqa: E501

        The email address that submitted form should be sent to.  # noqa: E501

        :return: The to of this InlineObject1.  # noqa: E501
        :rtype: str
        """
        return self._to

    @to.setter
    def to(self, to):
        """Sets the to of this InlineObject1.

        The email address that submitted form should be sent to.  # noqa: E501

        :param to: The to of this InlineObject1.  # noqa: E501
        :type: str
        """

        self._to = to

    @property
    def subject(self):
        """Gets the subject of this InlineObject1.  # noqa: E501

        Optional subject of the email that will be sent.  # noqa: E501

        :return: The subject of this InlineObject1.  # noqa: E501
        :rtype: str
        """
        return self._subject

    @subject.setter
    def subject(self, subject):
        """Sets the subject of this InlineObject1.

        Optional subject of the email that will be sent.  # noqa: E501

        :param subject: The subject of this InlineObject1.  # noqa: E501
        :type: str
        """

        self._subject = subject

    @property
    def email_address(self):
        """Gets the email_address of this InlineObject1.  # noqa: E501

        Email address of the submitting user. Include this if you wish to record the submitters email address and reply to it later.  # noqa: E501

        :return: The email_address of this InlineObject1.  # noqa: E501
        :rtype: str
        """
        return self._email_address

    @email_address.setter
    def email_address(self, email_address):
        """Sets the email_address of this InlineObject1.

        Email address of the submitting user. Include this if you wish to record the submitters email address and reply to it later.  # noqa: E501

        :param email_address: The email_address of this InlineObject1.  # noqa: E501
        :type: str
        """

        self._email_address = email_address

    @property
    def success_message(self):
        """Gets the success_message of this InlineObject1.  # noqa: E501

        Optional success message to display if no _redirectTo present.  # noqa: E501

        :return: The success_message of this InlineObject1.  # noqa: E501
        :rtype: str
        """
        return self._success_message

    @success_message.setter
    def success_message(self, success_message):
        """Sets the success_message of this InlineObject1.

        Optional success message to display if no _redirectTo present.  # noqa: E501

        :param success_message: The success_message of this InlineObject1.  # noqa: E501
        :type: str
        """

        self._success_message = success_message

    @property
    def spam_check(self):
        """Gets the spam_check of this InlineObject1.  # noqa: E501

        Optional but recommended field that catches spammers out. Include as a hidden form field but LEAVE EMPTY. Spam-bots will usually fill every field. If the _spamCheck field is filled the form submission will be ignored.  # noqa: E501

        :return: The spam_check of this InlineObject1.  # noqa: E501
        :rtype: str
        """
        return self._spam_check

    @spam_check.setter
    def spam_check(self, spam_check):
        """Sets the spam_check of this InlineObject1.

        Optional but recommended field that catches spammers out. Include as a hidden form field but LEAVE EMPTY. Spam-bots will usually fill every field. If the _spamCheck field is filled the form submission will be ignored.  # noqa: E501

        :param spam_check: The spam_check of this InlineObject1.  # noqa: E501
        :type: str
        """

        self._spam_check = spam_check

    @property
    def other_parameters(self):
        """Gets the other_parameters of this InlineObject1.  # noqa: E501

        All other parameters or fields will be accepted and attached to the sent email. This includes files and any HTML form field with a name. These fields will become the body of the email that is sent.  # noqa: E501

        :return: The other_parameters of this InlineObject1.  # noqa: E501
        :rtype: str
        """
        return self._other_parameters

    @other_parameters.setter
    def other_parameters(self, other_parameters):
        """Sets the other_parameters of this InlineObject1.

        All other parameters or fields will be accepted and attached to the sent email. This includes files and any HTML form field with a name. These fields will become the body of the email that is sent.  # noqa: E501

        :param other_parameters: The other_parameters of this InlineObject1.  # noqa: E501
        :type: str
        """

        self._other_parameters = other_parameters

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineObject1):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InlineObject1):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class CreateDevicePreviewFeedbackOptions(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'source': 'str',
        'category': 'str',
        'status': 'str',
        'rating': 'int',
        'run_id': 'str',
        'target_id': 'str',
        'screenshot_id': 'str',
        'provider': 'str',
        'title': 'str',
        'comment': 'str',
        'internal_note': 'str',
        'session_id': 'str',
        'live_view_url': 'str',
        'metadata': 'dict(str, str)'
    }

    attribute_map = {
        'source': 'source',
        'category': 'category',
        'status': 'status',
        'rating': 'rating',
        'run_id': 'runId',
        'target_id': 'targetId',
        'screenshot_id': 'screenshotId',
        'provider': 'provider',
        'title': 'title',
        'comment': 'comment',
        'internal_note': 'internalNote',
        'session_id': 'sessionId',
        'live_view_url': 'liveViewUrl',
        'metadata': 'metadata'
    }

    def __init__(self, source=None, category=None, status=None, rating=None, run_id=None, target_id=None, screenshot_id=None, provider=None, title=None, comment=None, internal_note=None, session_id=None, live_view_url=None, metadata=None, local_vars_configuration=None):  # noqa: E501
        """CreateDevicePreviewFeedbackOptions - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._source = None
        self._category = None
        self._status = None
        self._rating = None
        self._run_id = None
        self._target_id = None
        self._screenshot_id = None
        self._provider = None
        self._title = None
        self._comment = None
        self._internal_note = None
        self._session_id = None
        self._live_view_url = None
        self._metadata = None
        self.discriminator = None

        self.source = source
        self.category = category
        if status is not None:
            self.status = status
        if rating is not None:
            self.rating = rating
        if run_id is not None:
            self.run_id = run_id
        if target_id is not None:
            self.target_id = target_id
        if screenshot_id is not None:
            self.screenshot_id = screenshot_id
        if provider is not None:
            self.provider = provider
        if title is not None:
            self.title = title
        if comment is not None:
            self.comment = comment
        if internal_note is not None:
            self.internal_note = internal_note
        if session_id is not None:
            self.session_id = session_id
        if live_view_url is not None:
            self.live_view_url = live_view_url
        if metadata is not None:
            self.metadata = metadata

    @property
    def source(self):
        """Gets the source of this CreateDevicePreviewFeedbackOptions.  # noqa: E501


        :return: The source of this CreateDevicePreviewFeedbackOptions.  # noqa: E501
        :rtype: str
        """
        return self._source

    @source.setter
    def source(self, source):
        """Sets the source of this CreateDevicePreviewFeedbackOptions.


        :param source: The source of this CreateDevicePreviewFeedbackOptions.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and source is None:  # noqa: E501
            raise ValueError("Invalid value for `source`, must not be `None`")  # noqa: E501
        allowed_values = ["API_SERVICE", "LAB_USER", "END_USER", "SYSTEM"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and source not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `source` ({0}), must be one of {1}"  # noqa: E501
                .format(source, allowed_values)
            )

        self._source = source

    @property
    def category(self):
        """Gets the category of this CreateDevicePreviewFeedbackOptions.  # noqa: E501


        :return: The category of this CreateDevicePreviewFeedbackOptions.  # noqa: E501
        :rtype: str
        """
        return self._category

    @category.setter
    def category(self, category):
        """Sets the category of this CreateDevicePreviewFeedbackOptions.


        :param category: The category of this CreateDevicePreviewFeedbackOptions.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and category is None:  # noqa: E501
            raise ValueError("Invalid value for `category`, must not be `None`")  # noqa: E501
        allowed_values = ["GENERAL", "RUN_QUALITY", "SCREENSHOT_QUALITY", "PROVIDER_ISSUE", "BUG_REPORT", "FEATURE_REQUEST", "NOTE"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and category not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `category` ({0}), must be one of {1}"  # noqa: E501
                .format(category, allowed_values)
            )

        self._category = category

    @property
    def status(self):
        """Gets the status of this CreateDevicePreviewFeedbackOptions.  # noqa: E501


        :return: The status of this CreateDevicePreviewFeedbackOptions.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this CreateDevicePreviewFeedbackOptions.


        :param status: The status of this CreateDevicePreviewFeedbackOptions.  # noqa: E501
        :type: str
        """
        allowed_values = ["OPEN", "ACKNOWLEDGED", "RESOLVED", "DISMISSED"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and status not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}"  # noqa: E501
                .format(status, allowed_values)
            )

        self._status = status

    @property
    def rating(self):
        """Gets the rating of this CreateDevicePreviewFeedbackOptions.  # noqa: E501


        :return: The rating of this CreateDevicePreviewFeedbackOptions.  # noqa: E501
        :rtype: int
        """
        return self._rating

    @rating.setter
    def rating(self, rating):
        """Sets the rating of this CreateDevicePreviewFeedbackOptions.


        :param rating: The rating of this CreateDevicePreviewFeedbackOptions.  # noqa: E501
        :type: int
        """

        self._rating = rating

    @property
    def run_id(self):
        """Gets the run_id of this CreateDevicePreviewFeedbackOptions.  # noqa: E501


        :return: The run_id of this CreateDevicePreviewFeedbackOptions.  # noqa: E501
        :rtype: str
        """
        return self._run_id

    @run_id.setter
    def run_id(self, run_id):
        """Sets the run_id of this CreateDevicePreviewFeedbackOptions.


        :param run_id: The run_id of this CreateDevicePreviewFeedbackOptions.  # noqa: E501
        :type: str
        """

        self._run_id = run_id

    @property
    def target_id(self):
        """Gets the target_id of this CreateDevicePreviewFeedbackOptions.  # noqa: E501


        :return: The target_id of this CreateDevicePreviewFeedbackOptions.  # noqa: E501
        :rtype: str
        """
        return self._target_id

    @target_id.setter
    def target_id(self, target_id):
        """Sets the target_id of this CreateDevicePreviewFeedbackOptions.


        :param target_id: The target_id of this CreateDevicePreviewFeedbackOptions.  # noqa: E501
        :type: str
        """

        self._target_id = target_id

    @property
    def screenshot_id(self):
        """Gets the screenshot_id of this CreateDevicePreviewFeedbackOptions.  # noqa: E501


        :return: The screenshot_id of this CreateDevicePreviewFeedbackOptions.  # noqa: E501
        :rtype: str
        """
        return self._screenshot_id

    @screenshot_id.setter
    def screenshot_id(self, screenshot_id):
        """Sets the screenshot_id of this CreateDevicePreviewFeedbackOptions.


        :param screenshot_id: The screenshot_id of this CreateDevicePreviewFeedbackOptions.  # noqa: E501
        :type: str
        """

        self._screenshot_id = screenshot_id

    @property
    def provider(self):
        """Gets the provider of this CreateDevicePreviewFeedbackOptions.  # noqa: E501


        :return: The provider of this CreateDevicePreviewFeedbackOptions.  # noqa: E501
        :rtype: str
        """
        return self._provider

    @provider.setter
    def provider(self, provider):
        """Sets the provider of this CreateDevicePreviewFeedbackOptions.


        :param provider: The provider of this CreateDevicePreviewFeedbackOptions.  # noqa: E501
        :type: str
        """
        allowed_values = ["GMAIL", "OUTLOOK", "YAHOO"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and provider not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `provider` ({0}), must be one of {1}"  # noqa: E501
                .format(provider, allowed_values)
            )

        self._provider = provider

    @property
    def title(self):
        """Gets the title of this CreateDevicePreviewFeedbackOptions.  # noqa: E501


        :return: The title of this CreateDevicePreviewFeedbackOptions.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this CreateDevicePreviewFeedbackOptions.


        :param title: The title of this CreateDevicePreviewFeedbackOptions.  # noqa: E501
        :type: str
        """

        self._title = title

    @property
    def comment(self):
        """Gets the comment of this CreateDevicePreviewFeedbackOptions.  # noqa: E501


        :return: The comment of this CreateDevicePreviewFeedbackOptions.  # noqa: E501
        :rtype: str
        """
        return self._comment

    @comment.setter
    def comment(self, comment):
        """Sets the comment of this CreateDevicePreviewFeedbackOptions.


        :param comment: The comment of this CreateDevicePreviewFeedbackOptions.  # noqa: E501
        :type: str
        """

        self._comment = comment

    @property
    def internal_note(self):
        """Gets the internal_note of this CreateDevicePreviewFeedbackOptions.  # noqa: E501


        :return: The internal_note of this CreateDevicePreviewFeedbackOptions.  # noqa: E501
        :rtype: str
        """
        return self._internal_note

    @internal_note.setter
    def internal_note(self, internal_note):
        """Sets the internal_note of this CreateDevicePreviewFeedbackOptions.


        :param internal_note: The internal_note of this CreateDevicePreviewFeedbackOptions.  # noqa: E501
        :type: str
        """

        self._internal_note = internal_note

    @property
    def session_id(self):
        """Gets the session_id of this CreateDevicePreviewFeedbackOptions.  # noqa: E501


        :return: The session_id of this CreateDevicePreviewFeedbackOptions.  # noqa: E501
        :rtype: str
        """
        return self._session_id

    @session_id.setter
    def session_id(self, session_id):
        """Sets the session_id of this CreateDevicePreviewFeedbackOptions.


        :param session_id: The session_id of this CreateDevicePreviewFeedbackOptions.  # noqa: E501
        :type: str
        """

        self._session_id = session_id

    @property
    def live_view_url(self):
        """Gets the live_view_url of this CreateDevicePreviewFeedbackOptions.  # noqa: E501


        :return: The live_view_url of this CreateDevicePreviewFeedbackOptions.  # noqa: E501
        :rtype: str
        """
        return self._live_view_url

    @live_view_url.setter
    def live_view_url(self, live_view_url):
        """Sets the live_view_url of this CreateDevicePreviewFeedbackOptions.


        :param live_view_url: The live_view_url of this CreateDevicePreviewFeedbackOptions.  # noqa: E501
        :type: str
        """

        self._live_view_url = live_view_url

    @property
    def metadata(self):
        """Gets the metadata of this CreateDevicePreviewFeedbackOptions.  # noqa: E501


        :return: The metadata of this CreateDevicePreviewFeedbackOptions.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """Sets the metadata of this CreateDevicePreviewFeedbackOptions.


        :param metadata: The metadata of this CreateDevicePreviewFeedbackOptions.  # noqa: E501
        :type: dict(str, str)
        """

        self._metadata = metadata

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateDevicePreviewFeedbackOptions):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CreateDevicePreviewFeedbackOptions):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import mailslurp_client
from mailslurp_client.api.guest_portal_controller_api import GuestPortalControllerApi  # noqa: E501
from mailslurp_client.rest import ApiException


class TestGuestPortalControllerApi(unittest.TestCase):
    """GuestPortalControllerApi unit test stubs"""

    def setUp(self):
        self.api = mailslurp_client.api.guest_portal_controller_api.GuestPortalControllerApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_guest_portal(self):
        """Test case for create_guest_portal

        Create a portal page for your customers or clients to log into email accounts and view emails.  # noqa: E501
        """
        pass

    def test_create_guest_portal_user(self):
        """Test case for create_guest_portal_user

        Create a portal guest user  # noqa: E501
        """
        pass

    def test_get_all_guest_portal_users(self):
        """Test case for get_all_guest_portal_users

        Get all guest users for portal  # noqa: E501
        """
        pass

    def test_get_guest_portal(self):
        """Test case for get_guest_portal

        Get a client email portal  # noqa: E501
        """
        pass

    def test_get_guest_portal_user(self):
        """Test case for get_guest_portal_user

        Get guest user for portal  # noqa: E501
        """
        pass

    def test_get_guest_portal_user_by_id(self):
        """Test case for get_guest_portal_user_by_id

        Get guest user  # noqa: E501
        """
        pass

    def test_get_guest_portal_users(self):
        """Test case for get_guest_portal_users

        Get all guest users for portal  # noqa: E501
        """
        pass

    def test_get_guest_portals(self):
        """Test case for get_guest_portals

        Get guest portals  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class ConnectorEventDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'connector_id': 'str',
        'status': 'str',
        'event_type': 'str',
        'size': 'int',
        'message': 'str',
        'logs': 'str',
        'seen': 'bool',
        'created_at': 'datetime'
    }

    attribute_map = {
        'id': 'id',
        'connector_id': 'connectorId',
        'status': 'status',
        'event_type': 'eventType',
        'size': 'size',
        'message': 'message',
        'logs': 'logs',
        'seen': 'seen',
        'created_at': 'createdAt'
    }

    def __init__(self, id=None, connector_id=None, status=None, event_type=None, size=None, message=None, logs=None, seen=None, created_at=None, local_vars_configuration=None):  # noqa: E501
        """ConnectorEventDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._connector_id = None
        self._status = None
        self._event_type = None
        self._size = None
        self._message = None
        self._logs = None
        self._seen = None
        self._created_at = None
        self.discriminator = None

        self.id = id
        self.connector_id = connector_id
        self.status = status
        self.event_type = event_type
        self.size = size
        if message is not None:
            self.message = message
        if logs is not None:
            self.logs = logs
        if seen is not None:
            self.seen = seen
        self.created_at = created_at

    @property
    def id(self):
        """Gets the id of this ConnectorEventDto.  # noqa: E501


        :return: The id of this ConnectorEventDto.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ConnectorEventDto.


        :param id: The id of this ConnectorEventDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def connector_id(self):
        """Gets the connector_id of this ConnectorEventDto.  # noqa: E501


        :return: The connector_id of this ConnectorEventDto.  # noqa: E501
        :rtype: str
        """
        return self._connector_id

    @connector_id.setter
    def connector_id(self, connector_id):
        """Sets the connector_id of this ConnectorEventDto.


        :param connector_id: The connector_id of this ConnectorEventDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and connector_id is None:  # noqa: E501
            raise ValueError("Invalid value for `connector_id`, must not be `None`")  # noqa: E501

        self._connector_id = connector_id

    @property
    def status(self):
        """Gets the status of this ConnectorEventDto.  # noqa: E501


        :return: The status of this ConnectorEventDto.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this ConnectorEventDto.


        :param status: The status of this ConnectorEventDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and status is None:  # noqa: E501
            raise ValueError("Invalid value for `status`, must not be `None`")  # noqa: E501
        allowed_values = ["SUCCESS", "INTERNAL_ERROR", "SUBSCRIPTION_ERROR", "CONNECTION_ERROR", "NOT_FOUND"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and status not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}"  # noqa: E501
                .format(status, allowed_values)
            )

        self._status = status

    @property
    def event_type(self):
        """Gets the event_type of this ConnectorEventDto.  # noqa: E501


        :return: The event_type of this ConnectorEventDto.  # noqa: E501
        :rtype: str
        """
        return self._event_type

    @event_type.setter
    def event_type(self, event_type):
        """Sets the event_type of this ConnectorEventDto.


        :param event_type: The event_type of this ConnectorEventDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and event_type is None:  # noqa: E501
            raise ValueError("Invalid value for `event_type`, must not be `None`")  # noqa: E501
        allowed_values = ["SEND", "SYNC"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and event_type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `event_type` ({0}), must be one of {1}"  # noqa: E501
                .format(event_type, allowed_values)
            )

        self._event_type = event_type

    @property
    def size(self):
        """Gets the size of this ConnectorEventDto.  # noqa: E501


        :return: The size of this ConnectorEventDto.  # noqa: E501
        :rtype: int
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this ConnectorEventDto.


        :param size: The size of this ConnectorEventDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and size is None:  # noqa: E501
            raise ValueError("Invalid value for `size`, must not be `None`")  # noqa: E501

        self._size = size

    @property
    def message(self):
        """Gets the message of this ConnectorEventDto.  # noqa: E501


        :return: The message of this ConnectorEventDto.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this ConnectorEventDto.


        :param message: The message of this ConnectorEventDto.  # noqa: E501
        :type: str
        """

        self._message = message

    @property
    def logs(self):
        """Gets the logs of this ConnectorEventDto.  # noqa: E501


        :return: The logs of this ConnectorEventDto.  # noqa: E501
        :rtype: str
        """
        return self._logs

    @logs.setter
    def logs(self, logs):
        """Sets the logs of this ConnectorEventDto.


        :param logs: The logs of this ConnectorEventDto.  # noqa: E501
        :type: str
        """

        self._logs = logs

    @property
    def seen(self):
        """Gets the seen of this ConnectorEventDto.  # noqa: E501


        :return: The seen of this ConnectorEventDto.  # noqa: E501
        :rtype: bool
        """
        return self._seen

    @seen.setter
    def seen(self, seen):
        """Sets the seen of this ConnectorEventDto.


        :param seen: The seen of this ConnectorEventDto.  # noqa: E501
        :type: bool
        """

        self._seen = seen

    @property
    def created_at(self):
        """Gets the created_at of this ConnectorEventDto.  # noqa: E501


        :return: The created_at of this ConnectorEventDto.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this ConnectorEventDto.


        :param created_at: The created_at of this ConnectorEventDto.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_at is None:  # noqa: E501
            raise ValueError("Invalid value for `created_at`, must not be `None`")  # noqa: E501

        self._created_at = created_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ConnectorEventDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ConnectorEventDto):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class CampaignProbeRunComparisonDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'baseline': 'CampaignProbeRunDto',
        'current': 'CampaignProbeRunDto',
        'health_score_delta': 'int',
        'status_changed': 'bool',
        'link_issue_delta': 'int',
        'image_issue_delta': 'int',
        'compatibility_warning_delta': 'int',
        'compatibility_not_supported_delta': 'int',
        'html_error_delta': 'int',
        'html_warning_delta': 'int',
        'reputation_failure_delta': 'int',
        'attachment_mention_issue_delta': 'int',
        'added_insights': 'list[str]',
        'removed_insights': 'list[str]'
    }

    attribute_map = {
        'baseline': 'baseline',
        'current': 'current',
        'health_score_delta': 'healthScoreDelta',
        'status_changed': 'statusChanged',
        'link_issue_delta': 'linkIssueDelta',
        'image_issue_delta': 'imageIssueDelta',
        'compatibility_warning_delta': 'compatibilityWarningDelta',
        'compatibility_not_supported_delta': 'compatibilityNotSupportedDelta',
        'html_error_delta': 'htmlErrorDelta',
        'html_warning_delta': 'htmlWarningDelta',
        'reputation_failure_delta': 'reputationFailureDelta',
        'attachment_mention_issue_delta': 'attachmentMentionIssueDelta',
        'added_insights': 'addedInsights',
        'removed_insights': 'removedInsights'
    }

    def __init__(self, baseline=None, current=None, health_score_delta=None, status_changed=None, link_issue_delta=None, image_issue_delta=None, compatibility_warning_delta=None, compatibility_not_supported_delta=None, html_error_delta=None, html_warning_delta=None, reputation_failure_delta=None, attachment_mention_issue_delta=None, added_insights=None, removed_insights=None, local_vars_configuration=None):  # noqa: E501
        """CampaignProbeRunComparisonDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._baseline = None
        self._current = None
        self._health_score_delta = None
        self._status_changed = None
        self._link_issue_delta = None
        self._image_issue_delta = None
        self._compatibility_warning_delta = None
        self._compatibility_not_supported_delta = None
        self._html_error_delta = None
        self._html_warning_delta = None
        self._reputation_failure_delta = None
        self._attachment_mention_issue_delta = None
        self._added_insights = None
        self._removed_insights = None
        self.discriminator = None

        self.baseline = baseline
        self.current = current
        self.health_score_delta = health_score_delta
        self.status_changed = status_changed
        self.link_issue_delta = link_issue_delta
        self.image_issue_delta = image_issue_delta
        self.compatibility_warning_delta = compatibility_warning_delta
        self.compatibility_not_supported_delta = compatibility_not_supported_delta
        self.html_error_delta = html_error_delta
        self.html_warning_delta = html_warning_delta
        self.reputation_failure_delta = reputation_failure_delta
        self.attachment_mention_issue_delta = attachment_mention_issue_delta
        self.added_insights = added_insights
        self.removed_insights = removed_insights

    @property
    def baseline(self):
        """Gets the baseline of this CampaignProbeRunComparisonDto.  # noqa: E501


        :return: The baseline of this CampaignProbeRunComparisonDto.  # noqa: E501
        :rtype: CampaignProbeRunDto
        """
        return self._baseline

    @baseline.setter
    def baseline(self, baseline):
        """Sets the baseline of this CampaignProbeRunComparisonDto.


        :param baseline: The baseline of this CampaignProbeRunComparisonDto.  # noqa: E501
        :type: CampaignProbeRunDto
        """
        if self.local_vars_configuration.client_side_validation and baseline is None:  # noqa: E501
            raise ValueError("Invalid value for `baseline`, must not be `None`")  # noqa: E501

        self._baseline = baseline

    @property
    def current(self):
        """Gets the current of this CampaignProbeRunComparisonDto.  # noqa: E501


        :return: The current of this CampaignProbeRunComparisonDto.  # noqa: E501
        :rtype: CampaignProbeRunDto
        """
        return self._current

    @current.setter
    def current(self, current):
        """Sets the current of this CampaignProbeRunComparisonDto.


        :param current: The current of this CampaignProbeRunComparisonDto.  # noqa: E501
        :type: CampaignProbeRunDto
        """
        if self.local_vars_configuration.client_side_validation and current is None:  # noqa: E501
            raise ValueError("Invalid value for `current`, must not be `None`")  # noqa: E501

        self._current = current

    @property
    def health_score_delta(self):
        """Gets the health_score_delta of this CampaignProbeRunComparisonDto.  # noqa: E501


        :return: The health_score_delta of this CampaignProbeRunComparisonDto.  # noqa: E501
        :rtype: int
        """
        return self._health_score_delta

    @health_score_delta.setter
    def health_score_delta(self, health_score_delta):
        """Sets the health_score_delta of this CampaignProbeRunComparisonDto.


        :param health_score_delta: The health_score_delta of this CampaignProbeRunComparisonDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and health_score_delta is None:  # noqa: E501
            raise ValueError("Invalid value for `health_score_delta`, must not be `None`")  # noqa: E501

        self._health_score_delta = health_score_delta

    @property
    def status_changed(self):
        """Gets the status_changed of this CampaignProbeRunComparisonDto.  # noqa: E501


        :return: The status_changed of this CampaignProbeRunComparisonDto.  # noqa: E501
        :rtype: bool
        """
        return self._status_changed

    @status_changed.setter
    def status_changed(self, status_changed):
        """Sets the status_changed of this CampaignProbeRunComparisonDto.


        :param status_changed: The status_changed of this CampaignProbeRunComparisonDto.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and status_changed is None:  # noqa: E501
            raise ValueError("Invalid value for `status_changed`, must not be `None`")  # noqa: E501

        self._status_changed = status_changed

    @property
    def link_issue_delta(self):
        """Gets the link_issue_delta of this CampaignProbeRunComparisonDto.  # noqa: E501


        :return: The link_issue_delta of this CampaignProbeRunComparisonDto.  # noqa: E501
        :rtype: int
        """
        return self._link_issue_delta

    @link_issue_delta.setter
    def link_issue_delta(self, link_issue_delta):
        """Sets the link_issue_delta of this CampaignProbeRunComparisonDto.


        :param link_issue_delta: The link_issue_delta of this CampaignProbeRunComparisonDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and link_issue_delta is None:  # noqa: E501
            raise ValueError("Invalid value for `link_issue_delta`, must not be `None`")  # noqa: E501

        self._link_issue_delta = link_issue_delta

    @property
    def image_issue_delta(self):
        """Gets the image_issue_delta of this CampaignProbeRunComparisonDto.  # noqa: E501


        :return: The image_issue_delta of this CampaignProbeRunComparisonDto.  # noqa: E501
        :rtype: int
        """
        return self._image_issue_delta

    @image_issue_delta.setter
    def image_issue_delta(self, image_issue_delta):
        """Sets the image_issue_delta of this CampaignProbeRunComparisonDto.


        :param image_issue_delta: The image_issue_delta of this CampaignProbeRunComparisonDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and image_issue_delta is None:  # noqa: E501
            raise ValueError("Invalid value for `image_issue_delta`, must not be `None`")  # noqa: E501

        self._image_issue_delta = image_issue_delta

    @property
    def compatibility_warning_delta(self):
        """Gets the compatibility_warning_delta of this CampaignProbeRunComparisonDto.  # noqa: E501


        :return: The compatibility_warning_delta of this CampaignProbeRunComparisonDto.  # noqa: E501
        :rtype: int
        """
        return self._compatibility_warning_delta

    @compatibility_warning_delta.setter
    def compatibility_warning_delta(self, compatibility_warning_delta):
        """Sets the compatibility_warning_delta of this CampaignProbeRunComparisonDto.


        :param compatibility_warning_delta: The compatibility_warning_delta of this CampaignProbeRunComparisonDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and compatibility_warning_delta is None:  # noqa: E501
            raise ValueError("Invalid value for `compatibility_warning_delta`, must not be `None`")  # noqa: E501

        self._compatibility_warning_delta = compatibility_warning_delta

    @property
    def compatibility_not_supported_delta(self):
        """Gets the compatibility_not_supported_delta of this CampaignProbeRunComparisonDto.  # noqa: E501


        :return: The compatibility_not_supported_delta of this CampaignProbeRunComparisonDto.  # noqa: E501
        :rtype: int
        """
        return self._compatibility_not_supported_delta

    @compatibility_not_supported_delta.setter
    def compatibility_not_supported_delta(self, compatibility_not_supported_delta):
        """Sets the compatibility_not_supported_delta of this CampaignProbeRunComparisonDto.


        :param compatibility_not_supported_delta: The compatibility_not_supported_delta of this CampaignProbeRunComparisonDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and compatibility_not_supported_delta is None:  # noqa: E501
            raise ValueError("Invalid value for `compatibility_not_supported_delta`, must not be `None`")  # noqa: E501

        self._compatibility_not_supported_delta = compatibility_not_supported_delta

    @property
    def html_error_delta(self):
        """Gets the html_error_delta of this CampaignProbeRunComparisonDto.  # noqa: E501


        :return: The html_error_delta of this CampaignProbeRunComparisonDto.  # noqa: E501
        :rtype: int
        """
        return self._html_error_delta

    @html_error_delta.setter
    def html_error_delta(self, html_error_delta):
        """Sets the html_error_delta of this CampaignProbeRunComparisonDto.


        :param html_error_delta: The html_error_delta of this CampaignProbeRunComparisonDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and html_error_delta is None:  # noqa: E501
            raise ValueError("Invalid value for `html_error_delta`, must not be `None`")  # noqa: E501

        self._html_error_delta = html_error_delta

    @property
    def html_warning_delta(self):
        """Gets the html_warning_delta of this CampaignProbeRunComparisonDto.  # noqa: E501


        :return: The html_warning_delta of this CampaignProbeRunComparisonDto.  # noqa: E501
        :rtype: int
        """
        return self._html_warning_delta

    @html_warning_delta.setter
    def html_warning_delta(self, html_warning_delta):
        """Sets the html_warning_delta of this CampaignProbeRunComparisonDto.


        :param html_warning_delta: The html_warning_delta of this CampaignProbeRunComparisonDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and html_warning_delta is None:  # noqa: E501
            raise ValueError("Invalid value for `html_warning_delta`, must not be `None`")  # noqa: E501

        self._html_warning_delta = html_warning_delta

    @property
    def reputation_failure_delta(self):
        """Gets the reputation_failure_delta of this CampaignProbeRunComparisonDto.  # noqa: E501


        :return: The reputation_failure_delta of this CampaignProbeRunComparisonDto.  # noqa: E501
        :rtype: int
        """
        return self._reputation_failure_delta

    @reputation_failure_delta.setter
    def reputation_failure_delta(self, reputation_failure_delta):
        """Sets the reputation_failure_delta of this CampaignProbeRunComparisonDto.


        :param reputation_failure_delta: The reputation_failure_delta of this CampaignProbeRunComparisonDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and reputation_failure_delta is None:  # noqa: E501
            raise ValueError("Invalid value for `reputation_failure_delta`, must not be `None`")  # noqa: E501

        self._reputation_failure_delta = reputation_failure_delta

    @property
    def attachment_mention_issue_delta(self):
        """Gets the attachment_mention_issue_delta of this CampaignProbeRunComparisonDto.  # noqa: E501


        :return: The attachment_mention_issue_delta of this CampaignProbeRunComparisonDto.  # noqa: E501
        :rtype: int
        """
        return self._attachment_mention_issue_delta

    @attachment_mention_issue_delta.setter
    def attachment_mention_issue_delta(self, attachment_mention_issue_delta):
        """Sets the attachment_mention_issue_delta of this CampaignProbeRunComparisonDto.


        :param attachment_mention_issue_delta: The attachment_mention_issue_delta of this CampaignProbeRunComparisonDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and attachment_mention_issue_delta is None:  # noqa: E501
            raise ValueError("Invalid value for `attachment_mention_issue_delta`, must not be `None`")  # noqa: E501

        self._attachment_mention_issue_delta = attachment_mention_issue_delta

    @property
    def added_insights(self):
        """Gets the added_insights of this CampaignProbeRunComparisonDto.  # noqa: E501


        :return: The added_insights of this CampaignProbeRunComparisonDto.  # noqa: E501
        :rtype: list[str]
        """
        return self._added_insights

    @added_insights.setter
    def added_insights(self, added_insights):
        """Sets the added_insights of this CampaignProbeRunComparisonDto.


        :param added_insights: The added_insights of this CampaignProbeRunComparisonDto.  # noqa: E501
        :type: list[str]
        """
        if self.local_vars_configuration.client_side_validation and added_insights is None:  # noqa: E501
            raise ValueError("Invalid value for `added_insights`, must not be `None`")  # noqa: E501

        self._added_insights = added_insights

    @property
    def removed_insights(self):
        """Gets the removed_insights of this CampaignProbeRunComparisonDto.  # noqa: E501


        :return: The removed_insights of this CampaignProbeRunComparisonDto.  # noqa: E501
        :rtype: list[str]
        """
        return self._removed_insights

    @removed_insights.setter
    def removed_insights(self, removed_insights):
        """Sets the removed_insights of this CampaignProbeRunComparisonDto.


        :param removed_insights: The removed_insights of this CampaignProbeRunComparisonDto.  # noqa: E501
        :type: list[str]
        """
        if self.local_vars_configuration.client_side_validation and removed_insights is None:  # noqa: E501
            raise ValueError("Invalid value for `removed_insights`, must not be `None`")  # noqa: E501

        self._removed_insights = removed_insights

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CampaignProbeRunComparisonDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CampaignProbeRunComparisonDto):
            return True

        return self.to_dict() != other.to_dict()
